urn_nbn_api.api_structures.digital_instance module
==================================================

.. automodule:: urn_nbn_api.api_structures.digital_instance
    :members:
    :undoc-members:
    :show-inheritance:
